==> jdk-11.0.29.7.1p1v0.tgz: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_ms.java <==
/*
 * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_ms extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final String metaValue_ERN = "ERN";
        final Object[][] data = new Object[][] {
            { "mwk", "Kwacha Malawi" },
            { "FJD", "FJD" },
            { "MXN", "MXN" },
            { "STD", "STD" },
            { "LVL", "LVL" },
            { "SCR", "SCR" },
            { "CDF", "CDF" },
            { "BBD", "BBD" },
            { "mga", "Ariary Malagasy" },
            { "HNL", "HNL" },
            { "UGX", "UGX" },
            { "ZAR", "ZAR" },
            { "bam", "Mark Boleh Tukar Bosnia-Herzegovina" },
            { "egp", "Paun Mesir" },
            { "CUC", "CUC" },
            { "ssp", "Paun Sudan selatan" },
            { "BSD", "BSD" },
            { "nio", "Cordoba Nicaragua" },
            { "SDG", "SDG" },
            { "nzd", "Dolar New Zealand" },
            { "IQD", "IQD" },
            { "brl", "Real Brazil" },
            { "CUP", "CUP" },
            { "GMD", "GMD" },
            { "fjd", "Dolar Fiji" },
            { "RSD", "RSD" },
            { "mxn", "Peso Mexico" },
            { "std", "Dobra Sao Tome dan Principe (1977\u20132017)" },
            { "lvl", "Lats Latvia" },
            { "scr", "Rupee Seychelles" },
            { "cdf", "Franc Congo" },
            { "bbd", "Dolar Barbados" },
            { "MYR", "RM" },
            { "hnl", "Lempira Honduras" },
            { "ugx", "Syiling Uganda" },
            { "FKP", "FKP" },
            { "zar", "Rand Afrika Selatan" },
            { "stn", "Dobra Sao Tome dan Principe" },
            { "UYU", "UYU" },
            { "cuc", "Peso Boleh Tukar Cuba" },
            { "bsd", "Dolar Bahamas" },
            { "CVE", "CVE" },
            { "OMR", "OMR" },
            { "sdg", "Paun Sudan" },
            { "KES", "KES" },
            { "SEK", "SEK" },
            { "BTN", "BTN" },
            { "iqd", "Dinar Iraq" },
            { "GNF", "GNF" },
            { "cup", "Peso Cuba" },
            { "gmd", "Dalasi Gambia" },
            { "MZN", "MZN" },
            { "twd", "Dolar Taiwan Baru" },
            { "ARS", "ARS" },
            { "rsd", "Dinar Serbia" },
            { "QAR", "QAR" },
            { "myr", "Ringgit Malaysia" },
            { "IRR", "IRR" },
            { "fkp", "Paun Kepulauan Falkland" },
            { "xof", "Franc CFA BCEAO" },
            { "THB", "THB" },
            { "UZS", "UZS" },
            { "uyu", "Peso Uruguay" },
            { "BDT", "BDT" },
            { "cve", "Escudo Tanjung Verde" },
            { "omr", "Rial Oman" },
            { "LYD", "LYD" },
            { "kes", "Syiling Kenya" },
            { "sek", "Krona Sweden" },
            { "KWD", "KWD" },
            { "btn", "Ngultrum Bhutan" },
            { "RUB", "RUB" },
            { "gnf", "Franc Guinea" },
            { "ISK", "ISK" },
            { "mzn", "Metikal Mozambique" },
            { "ars", "Peso Argentina" },
            { "qar", "Rial Qatar" },
            { "MKD", "MKD" },
            { "irr", "Rial Iran" },
            { "DZD", "DZD" },
            { "thb", "Baht Thai" },
            { "uzs", "Som Uzbekistan" },
            { "xpf", "Franc CFP" },
            { "PAB", "PAB" },
            { "SGD", "SGD" },
            { "bdt", "Taka Bangladesh" },
            { "KGS", "KGS" },
            { "lyd", "Dinar Libya" },
            { "kwd", "Dinar Kuwait" },
            { "rub", "Rubel Rusia" },
            { "CHF", "CHF" },
            { "HRK", "HRK" },
            { "isk", "Krona Iceland" },
            { "DJF", "DJF" },
            { "mkd", "Denar Macedonia" },
            { "TZS", "TZS" },
            { "dzd", "Dinar Algeria" },
            { "pab", "Balboa Panama" },
            { "sgd", "Dolar Singapura" },
            { "KHR", "KHR" },
            { "IDR", "IDR" },
            { "kgs", "Som Kyrgystani" },
            { "KYD", "KYD" },
            { "BWP", "BWP" },
            { "SHP", "SHP" },
            { "TJS", "TJS" },
            { "xaf", "Franc CFA BEAC" },
            { "AED", "AED" },
            { "RWF", "RWF" },
            { "chf", "Franc Switzerland" },
            { "hrk", "Kuna Croatia" },
            { "djf", "Franc Djibouti" },
            { "DKK", "DKK" },
            { "BGN", "BGN" },
            { "MMK", "MMK" },
            { "NOK", "NOK" },
            { "SYP", "SYP" },
            { "tzs", "Syiling Tanzania" },
            { "vnd", "Dong Vietnam" },
            { "aud", "Dolar Australia" },
            { "LKR", "LKR" },
            { "khr", "Riel Kemboja" },
            { "CZK", "CZK" },
            { "idr", "Rupiah Indonesia" },
            { "kyd", "Dolar Kepulauan Cayman" },
            { "HTG", "HTG" },
            { "bwp", "Pula Botswana" },
            { "shp", "Paun Saint Helena" },
            { "tjs", "Somoni Tajikistan" },
            { "BHD", "BHD" },
            { "rwf", "Franc Rwanda" },
            { "aed", "Dirham Emiriah Arab Bersatu" },
            { "KZT", "KZT" },
            { "SZL", "SZL" },
            { "dkk", "Krone Denmark" },
            { "YER", "YER" },
            { "bgn", "Lev Bulgaria" },
            { "AFN", "AFN" },
            { "mmk", "Kyat Myanma" },
            { "nok", "Krone Norway" },
            { "syp", "Paun Syria" },
            { "AWG", "AWG" },
            { "NPR", "NPR" },
            { "MNT", "MNT" },
            { "lkr", "Rupee Sri Lanka" },
            { "czk", "Koruna Republik Czech" },
            { "BYN", "BYN" },
            { "HUF", "HUF" },
            { "xcd", "Dolar Caribbean Timur" },
            { "BYR", "BYR" },
            { "htg", "Gourde Haiti" },
            { "BIF", "BIF" },
            { "bhd", "Dinar Bahrain" },
            { "kzt", "Tenge Kazakhstan" },
            { "szl", "Lilangeni Swazi" },
            { "yer", "Rial Yaman" },
            { "afn", "Afghani Afghanistan" },
            { "BZD", "BZD" },
            { "MOP", "MOP" },
            { "NAD", "NAD" },
            { "awg", "Florin Aruba" },
            { "npr", "Rupee Nepal" },
            { "mnt", "Tugrik Mongolia" },
            { "gbp", "Paun British" },
            { "byn", "Rubel Belarus baharu" },
            { "PEN", "PEN" },
            { "huf", "Forint Hungary" },
            { "WST", "WST" },
            { "TMT", "TMT" },
            { "byr", "Rubel Belarus (2000\u20132016)" },
            { "bif", "Franc Burundi" },
            { "GTQ", "GTQ" },
            { "CLP", "CLP" },
            { "TND", "TND" },
            { "bzd", "Dolar Belize" },
            { "mop", "Pataca Macau" },
            { "nad", "Dolar Namibia" },
            { "SLL", "SLL" },
            { "pen", "Sol Peru" },
            { "wst", "Tala Samoa" },
            { "tmt", "Manat Turkmenistan" },
            { "DOP", "DOP" },
            { "KMF", "KMF" },
            { "gtq", "Quetzal Guatemala" },
            { "clp", "Peso Chile" },
            { "tnd", "Dinar Tunisia" },
            { "GEL", "GEL" },
            { "MAD", "MAD" },
            { "sll", "Leone Sierra Leone" },
            { "TOP", "TOP" },
            { "AZN", "AZN" },
            { "PGK", "PGK" },
            { "CNH", "CNH" },
            { "UAH", "UAH" },
            { "ERN", metaValue_ERN },
            { "dop", "Peso Dominican" },
            { "kmf", "Franc Comoria" },
            { "MRO", "MRO" },
            { "gel", "Lari Georgia" },
            { "mad", "Dirham Maghribi" },
            { "azn", "Manat Azerbaijan" },
            { "top", "Pa\u2019anga Tonga" },
            { "pgk", "Kina Papua New Guinea" },
            { "BMD", "BMD" },
            { "PHP", "PHP" },
            { "cnh", "Yuan China (luar pesisir)" },
            { "uah", "Hryvnia Ukraine" },
            { "PYG", "PYG" },
            { "ern", metaValue_ERN },
            { "JMD", "JMD" },
            { "COP", "COP" },
            { "USD", "USD" },
            { "mro", "Ouguiya Mauritania (1973\u20132017)" },
            { "cny", "Yuan Cina" },
            { "mru", "Ouguiya Mauritania" },
            { "ETB", "ETB" },
            { "SOS", "SOS" },
            { "VEF", "VEF" },
            { "VUV", "VUV" },
            { "LAK", "LAK" },
            { "bmd", "Dolar Bermuda" },
            { "BND", "BND" },
            { "ZMK", "ZMK" },
            { "php", "Peso Filipina" },
            { "xxx", "Mata Wang Tidak Diketahui" },
            { "LRD", "LRD" },
            { "pyg", "Guarani Paraguay" },
            { "jmd", "Dolar Jamaica" },
            { "ALL", "ALL" },
            { "ZMW", "ZMW" },
            { "cop", "Peso Colombia" },
            { "usd", "Dolar AS" },
            { "etb", "Birr Ethiopia" },
            { "GHS", "GHS" },
            { "GYD", "GYD" },
            { "KPW", "KPW" },
            { "BOB", "BOB" },
            { "MDL", "MDL" },
            { "sos", "Syiling Somali" },
            { "vef", "Bolivar Venezuela" },
            { "vuv", "Vatu Vanuatu" },
            { "lak", "Kip Laos" },
            { "AMD", "AMD" },
            { "bnd", "Dolar Brunei" },
            { "zmk", "Kwacha Zambia (1968\u20132012)" },
            { "TRY", "TRY" },
            { "LBP", "LBP" },
            { "JOD", "JOD" },
            { "lrd", "Dolar Liberia" },
            { "all", "Lek Albania" },
            { "zmw", "Kwacha Zambia" },
            { "CAD", "CAD" },
            { "MUR", "MUR" },
            { "GIP", "GIP" },
            { "RON", "RON" },
            { "ils", "Syekel Baharu Israel" },
            { "ghs", "Cedi Ghana" },
            { "gyd", "Dolar Guyana" },
            { "kpw", "Won Korea Utara" },
            { "NGN", "NGN" },
            { "bob", "Boliviano Bolivia" },
            { "mdl", "Leu Moldova" },
            { "CRC", "CRC" },
            { "PKR", "PKR" },
            { "amd", "Dram Armenia" },
            { "ANG", "ANG" },
            { "try", "Lira Turki" },
            { "lbp", "Paun Lubnan" },
            { "jod", "Dinar Jordan" },
            { "hkd", "Dolar Hong Kong" },
            { "eur", "Euro" },
            { "SRD", "SRD" },
            { "lsl", "Loti Lesotho" },
            { "LTL", "LTL" },
            { "SAR", "SAR" },
            { "TTD", "TTD" },
            { "cad", "Dolar Kanada" },
            { "MVR", "MVR" },
            { "mur", "Rupee Mauritius" },
            { "gip", "Paun Gibraltar" },
            { "ron", "Leu Romania" },
            { "AOA", "AOA" },
            { "PLN", "PLN" },
            { "SBD", "SBD" },
            { "ngn", "Naira Nigeria" },
            { "crc", "Colon Costa Rica" },
            { "pkr", "Rupee Pakistan" },
            { "ang", "Guilder Antillen Belanda" },
            { "MWK", "MWK" },
            { "srd", "Dolar Surinam" },
            { "ltl", "Litas Lithuania" },
            { "sar", "Riyal Saudi" },
            { "ttd", "Dolar Trinidad dan Tobago" },
            { "MGA", "MGA" },
            { "mvr", "Rufiyaa Maldives" },
            { "inr", "Rupee India" },
            { "BAM", "BAM" },
            { "EGP", "EGP" },
            { "SSP", "SSP" },
            { "krw", "Won Korea Selatan" },
            { "aoa", "Kwanza Angola" },
            { "jpy", "Yen Jepun" },
            { "pln", "Zloty Poland" },
            { "sbd", "Dolar Kepulauan Solomon" },
            { "NIO", "NIO" },
        };
        return data;
    }
}

==> jdk-17.0.2.8.1v0.tgz: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_ms.java <==
/*
 * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_ms extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "AED", "AED" },
            { "AFN", "AFN" },
            { "ALL", "ALL" },
            { "AMD", "AMD" },
            { "ANG", "ANG" },
            { "AOA", "AOA" },
            { "ARS", "ARS" },
            { "AWG", "AWG" },
            { "AZN", "AZN" },
            { "BAM", "BAM" },
            { "BBD", "BBD" },
            { "BDT", "BDT" },
            { "BGN", "BGN" },
            { "BHD", "BHD" },
            { "BIF", "BIF" },
            { "BMD", "BMD" },
            { "BND", "BND" },
            { "BOB", "BOB" },
            { "BSD", "BSD" },
            { "BTN", "BTN" },
            { "BWP", "BWP" },
            { "BYN", "BYN" },
            { "BYR", "BYR" },
            { "BZD", "BZD" },
            { "CAD", "CAD" },
            { "CDF", "CDF" },
            { "CHF", "CHF" },
            { "CLP", "CLP" },
            { "CNH", "CNH" },
            { "COP", "COP" },
            { "CRC", "CRC" },
            { "CUC", "CUC" },
            { "CUP", "CUP" },
            { "CVE", "CVE" },
            { "CZK", "CZK" },
            { "DJF", "DJF" },
            { "DKK", "DKK" },
            { "DOP", "DOP" },
            { "DZD", "DZD" },
            { "EGP", "EGP" },
            { "ERN", "ERN" },
            { "ETB", "ETB" },
            { "FJD", "FJD" },
            { "FKP", "FKP" },
            { "GEL", "GEL" },
            { "GHS", "GHS" },
            { "GIP", "GIP" },
            { "GMD", "GMD" },
            { "GNF", "GNF" },
            { "GTQ", "GTQ" },
            { "GYD", "GYD" },
            { "HNL", "HNL" },
            { "HRK", "HRK" },
            { "HTG", "HTG" },
            { "HUF", "HUF" },
            { "IDR", "IDR" },
            { "IQD", "IQD" },
            { "IRR", "IRR" },
            { "ISK", "ISK" },
            { "JMD", "JMD" },
            { "JOD", "JOD" },
            { "KES", "KES" },
            { "KGS", "KGS" },
            { "KHR", "KHR" },
            { "KMF", "KMF" },
            { "KPW", "KPW" },
            { "KWD", "KWD" },
            { "KYD", "KYD" },
            { "KZT", "KZT" },
            { "LAK", "LAK" },
            { "LBP", "LBP" },
            { "LKR", "LKR" },
            { "LRD", "LRD" },
            { "LTL", "LTL" },
            { "LVL", "LVL" },
            { "LYD", "LYD" },
            { "MAD", "MAD" },
            { "MDL", "MDL" },
            { "MGA", "MGA" },
            { "MKD", "MKD" },
            { "MMK", "MMK" },
            { "MNT", "MNT" },
            { "MOP", "MOP" },
            { "MRO", "MRO" },
            { "MRU", "MRU" },
            { "MUR", "MUR" },
            { "MVR", "MVR" },
            { "MWK", "MWK" },
            { "MXN", "MXN" },
            { "MYR", "RM" },
            { "MZN", "MZN" },
            { "NAD", "NAD" },
            { "NGN", "NGN" },
            { "NIO", "NIO" },
            { "NOK", "NOK" },
            { "NPR", "NPR" },
            { "OMR", "OMR" },
            { "PAB", "PAB" },
            { "PEN", "PEN" },
            { "PGK", "PGK" },
            { "PHP", "PHP" },
            { "PKR", "PKR" },
            { "PLN", "PLN" },
            { "PYG", "PYG" },
            { "QAR", "QAR" },
            { "RON", "RON" },
            { "RSD", "RSD" },
            { "RUB", "RUB" },
            { "RWF", "RWF" },
            { "SAR", "SAR" },
            { "SBD", "SBD" },
            { "SCR", "SCR" },
            { "SDG", "SDG" },
            { "SEK", "SEK" },
            { "SGD", "SGD" },
            { "SHP", "SHP" },
            { "SLL", "SLL" },
            { "SOS", "SOS" },
            { "SRD", "SRD" },
            { "SSP", "SSP" },
            { "STD", "STD" },
            { "STN", "STN" },
            { "SYP", "SYP" },
            { "SZL", "SZL" },
            { "THB", "THB" },
            { "TJS", "TJS" },
            { "TMT", "TMT" },
            { "TND", "TND" },
            { "TOP", "TOP" },
            { "TRY", "TRY" },
            { "TTD", "TTD" },
            { "TZS", "TZS" },
            { "UAH", "UAH" },
            { "UGX", "UGX" },
            { "USD", "USD" },
            { "UYU", "UYU" },
            { "UZS", "UZS" },
            { "VEF", "VEF" },
            { "VES", "VES" },
            { "VUV", "VUV" },
            { "WST", "WST" },
            { "YER", "YER" },
            { "ZAR", "ZAR" },
            { "ZMK", "ZMK" },
            { "ZMW", "ZMW" },
            { "aed", "Dirham Emiriah Arab Bersatu" },
            { "afn", "Afghani Afghanistan" },
            { "all", "Lek Albania" },
            { "amd", "Dram Armenia" },
            { "ang", "Guilder Antillen Belanda" },
            { "aoa", "Kwanza Angola" },
            { "ars", "Peso Argentina" },
            { "aud", "Dolar Australia" },
            { "awg", "Florin Aruba" },
            { "azn", "Manat Azerbaijan" },
            { "bam", "Mark Boleh Tukar Bosnia-Herzegovina" },
            { "bbd", "Dolar Barbados" },
            { "bdt", "Taka Bangladesh" },
            { "bgn", "Lev Bulgaria" },
            { "bhd", "Dinar Bahrain" },
            { "bif", "Franc Burundi" },
            { "bmd", "Dolar Bermuda" },
            { "bnd", "Dolar Brunei" },
            { "bob", "Boliviano Bolivia" },
            { "brl", "Real Brazil" },
            { "bsd", "Dolar Bahamas" },
            { "btn", "Ngultrum Bhutan" },
            { "bwp", "Pula Botswana" },
            { "byn", "Rubel Belarus baharu" },
            { "byr", "Rubel Belarus (2000\u20132016)" },
            { "bzd", "Dolar Belize" },
            { "cad", "Dolar Kanada" },
            { "cdf", "Franc Congo" },
            { "chf", "Franc Switzerland" },
            { "clp", "Peso Chile" },
            { "cnh", "Yuan China (luar pesisir)" },
            { "cny", "Yuan Cina" },
            { "cop", "Peso Colombia" },
            { "crc", "Colon Costa Rica" },
            { "cuc", "Peso Boleh Tukar Cuba" },
            { "cup", "Peso Cuba" },
            { "cve", "Escudo Tanjung Verde" },
            { "czk", "Koruna Republik Czech" },
            { "djf", "Franc Djibouti" },
            { "dkk", "Krone Denmark" },
            { "dop", "Peso Dominican" },
            { "dzd", "Dinar Algeria" },
            { "egp", "Paun Mesir" },
            { "ern", "Nakfa Eritrea" },
            { "etb", "Birr Ethiopia" },
            { "eur", "Euro" },
            { "fjd", "Dolar Fiji" },
            { "fkp", "Paun Kepulauan Falkland" },
            { "gbp", "Paun British" },
            { "gel", "Lari Georgia" },
            { "ghs", "Cedi Ghana" },
            { "gip", "Paun Gibraltar" },
            { "gmd", "Dalasi Gambia" },
            { "gnf", "Franc Guinea" },
            { "gtq", "Quetzal Guatemala" },
            { "gyd", "Dolar Guyana" },
            { "hkd", "Dolar Hong Kong" },
            { "hnl", "Lempira Honduras" },
            { "hrk", "Kuna Croatia" },
            { "htg", "Gourde Haiti" },
            { "huf", "Forint Hungary" },
            { "idr", "Rupiah Indonesia" },
            { "ils", "Syekel Baharu Israel" },
            { "inr", "Rupee India" },
            { "iqd", "Dinar Iraq" },
            { "irr", "Rial Iran" },
            { "isk", "Krona Iceland" },
            { "jmd", "Dolar Jamaica" },
            { "jod", "Dinar Jordan" },
            { "jpy", "Yen Jepun" },
            { "kes", "Syiling Kenya" },
            { "kgs", "Som Kyrgystani" },
            { "khr", "Riel Kemboja" },
            { "kmf", "Franc Comoria" },
            { "kpw", "Won Korea Utara" },
            { "krw", "Won Korea Selatan" },
            { "kwd", "Dinar Kuwait" },
            { "kyd", "Dolar Kepulauan Cayman" },
            { "kzt", "Tenge Kazakhstan" },
            { "lak", "Kip Laos" },
            { "lbp", "Paun Lubnan" },
            { "lkr", "Rupee Sri Lanka" },
            { "lrd", "Dolar Liberia" },
            { "lsl", "Loti Lesotho" },
            { "ltl", "Litas Lithuania" },
            { "lvl", "Lats Latvia" },
            { "lyd", "Dinar Libya" },
            { "mad", "Dirham Maghribi" },
            { "mdl", "Leu Moldova" },
            { "mga", "Ariary Malagasy" },
            { "mgf", "Franc Malagasy" },
            { "mkd", "Denar Macedonia" },
            { "mmk", "Kyat Myanma" },
            { "mnt", "Tugrik Mongolia" },
            { "mop", "Pataca Macau" },
            { "mro", "Ouguiya Mauritania (1973\u20132017)" },
            { "mru", "Ouguiya Mauritania" },
            { "mur", "Rupee Mauritius" },
            { "mvr", "Rufiyaa Maldives" },
            { "mwk", "Kwacha Malawi" },
            { "mxn", "Peso Mexico" },
            { "myr", "Ringgit Malaysia" },
            { "mze", "Escudo Mozambique" },
            { "mzm", "Metical Mozambique (1980\u20132006)" },
            { "mzn", "Metikal Mozambique" },
            { "nad", "Dolar Namibia" },
            { "ngn", "Naira Nigeria" },
            { "nio", "Cordoba Nicaragua" },
            { "nok", "Krone Norway" },
            { "npr", "Rupee Nepal" },
            { "nzd", "Dolar New Zealand" },
            { "omr", "Rial Oman" },
            { "pab", "Balboa Panama" },
            { "pen", "Sol Peru" },
            { "pgk", "Kina Papua New Guinea" },
            { "php", "Peso Filipina" },
            { "pkr", "Rupee Pakistan" },
            { "pln", "Zloty Poland" },
            { "pyg", "Guarani Paraguay" },
            { "qar", "Rial Qatar" },
            { "rhd", "Dolar Rhodesia" },
            { "ron", "Leu Romania" },
            { "rsd", "Dinar Serbia" },
            { "rub", "Rubel Rusia" },
            { "rwf", "Franc Rwanda" },
            { "sar", "Riyal Saudi" },
            { "sbd", "Dolar Kepulauan Solomon" },
            { "scr", "Rupee Seychelles" },
            { "sdg", "Paun Sudan" },
            { "sek", "Krona Sweden" },
            { "sgd", "Dolar Singapura" },
            { "shp", "Paun Saint Helena" },
            { "sll", "Leone Sierra Leone" },
            { "sos", "Syiling Somali" },
            { "srd", "Dolar Surinam" },
            { "ssp", "Paun Sudan selatan" },
            { "std", "Dobra Sao Tome dan Principe (1977\u20132017)" },
            { "stn", "Dobra Sao Tome dan Principe" },
            { "syp", "Paun Syria" },
            { "szl", "Lilangeni Swazi" },
            { "thb", "Baht Thai" },
            { "tjs", "Somoni Tajikistan" },
            { "tmt", "Manat Turkmenistan" },
            { "tnd", "Dinar Tunisia" },
            { "top", "Pa\u2019anga Tonga" },
            { "try", "Lira Turki" },
            { "ttd", "Dolar Trinidad dan Tobago" },
            { "twd", "Dolar Taiwan Baru" },
            { "tzs", "Syiling Tanzania" },
            { "uah", "Hryvnia Ukraine" },
            { "ugs", "Shilling Uganda (1966\u20131987)" },
            { "ugx", "Syiling Uganda" },
            { "usd", "Dolar AS" },
            { "uyu", "Peso Uruguay" },
            { "uzs", "Som Uzbekistan" },
            { "vef", "Bolivar Venezuela (2008\u20132018)" },
            { "ves", "Bolivar Venezuela" },
            { "vnd", "Dong Vietnam" },
            { "vuv", "Vatu Vanuatu" },
            { "wst", "Tala Samoa" },
            { "xaf", "Franc CFA BEAC" },
            { "xcd", "Dolar Caribbean Timur" },
            { "xof", "Franc CFA BCEAO" },
            { "xpf", "Franc CFP" },
            { "xxx", "Mata Wang Tidak Diketahui" },
            { "yer", "Rial Yaman" },
            { "zar", "Rand Afrika Selatan" },
            { "zmk", "Kwacha Zambia (1968\u20132012)" },
            { "zmw", "Kwacha Zambia" },
            { "zwd", "Dolar Zimbabwe (1980\u20132008)" },
            { "zwl", "Dolar Zimbabwe (2009)" },
            { "zwr", "Dolar Zimbabwe (2008)" },
        };
        return data;
    }
}
